@@ -4,8 +4,10 @@ Run commands on the native host, outside of any container image.
 
 import os
 import shutil
+from subprocess import CalledProcessError
+from typing import Iterable
 from ..types import RunnerTestResults
-from ..util import exec_or_return
+from ..util import capture_output, exec_or_return
 
 
 def register_arguments(parser) -> None:
@@ -15,10 +17,14 @@ def register_arguments(parser) -> None:
     pass
 
 
-def run(opts, argv, working_volume = None, extra_env = {}) -> int:
+def run(opts, argv, working_volume = None, extra_env = {}, cpus: int = None, memory: int = None) -> int:
     if working_volume:
         os.chdir(str(working_volume.src))
 
+    # XXX TODO: In the future we might want to set rlimits based on cpus and
+    # memory, at least on POSIX systems.
+    #   -trs, 21 May 2020
+
     return exec_or_return(argv, extra_env)
 
 
@@ -42,9 +48,13 @@ def update() -> bool:
     return True
 
 
-def print_version() -> None:
-    # XXX TODO: Show the versions of augur and auspice once those have
-    # command-line interfaces to printing their versions (and the versions of
-    # tools like mafft, FastTree, etc).
-    #   -trs, 17 August 2018
-    pass
+def versions() -> Iterable[str]:
+    try:
+        yield capture_output(["augur", "--version"])[0]
+    except (OSError, CalledProcessError):
+        pass
+
+    try:
+        yield "auspice " + capture_output(["auspice", "--version"])[0]
+    except (OSError, CalledProcessError):
+        pass
